ATP3011 is text speech LSI by AquesTalk pico. This librarry supports I2C interface and "printf()" C format. If ATP3011 talk number or alphabet you select printf(), otherwise, you have to use speech(). When you use printf(), the string must have "\n".

Revision:
1:18e2be0c89a4
Parent:
0:f4577c59b4f5
--- a/ATP3011.h	Mon Sep 14 06:46:02 2015 +0000
+++ b/ATP3011.h	Mon Oct 19 02:53:39 2015 +0000
@@ -1,22 +1,22 @@
 /**  ATP3011 is Texs Speach LSI by AquesTalk.
  * This librarry supports I2C interface and "printf()" C format.
  * If ATP3011 talk number or alphabet you select printf(), 
  * otherwise, you have to use speach().
  * When you use printf(), the string must have "\n".
  *
- * EX. code.
- *  
+ * @code.
  * I2C i2c(p9, p10);
  * ATP3011 talk(i2c);
  * //or ATP3011 talk(p9, p10);
- * talk.speach("#K");
- * talk.speach("tesu'to.");
+ * talk.speech("#K");
+ * talk.speech("tesu'to.");
  * talk.printf("denwaba'ngo-wa,<NUM VAL=0%d-%d-%d>,desu'.\n", 120, 123, 456);
  * char *chr= "abc123";
  * talk.printf("nyu-ryoku wa <ALPHA VAL=%s> de'su.\n", chr);
  * float dist= 3.14;
  * int lateTime= 7;
  * talk.printf("konosaki;<NUMK VAL=%.2f COUNTER=kiro>/ju-taichu-.tu-kadi'kann wa;<NUMK VAL=%d COUNTER=funn> de'su.\n", dist, lateTime);
+ * @endcode
  */
  
 #pragma once
@@ -36,14 +36,14 @@
     static const int ERR_I2C, ERR_OTHER, ERR_TooLeng;
     
     // if you send number or alphabet, you can use printf().
     // oterwise, you have to use speach().
     
-    /** speach message.
+    /** speech message.
      *  @param msg; if string, it's necessaly ".".
      *  @param timeout; if 0 ms, func wait to ready without timeout.
      *  @return; above Return message.
      */
-    int speach(const char *msg, int timeout_ms= 0);
+    int speech(const char *msg, int timeout_ms= 0);
     
     /** check Busy.
      *  @return;    READY, BUSY, ERR_I2C, ERR_OTHER.
@@ -1,22 +1,22 @@
-/**  ATP3011 is Texs Speach LSI by AquesTalk.
+/**  ATP3011 is Text Speech LSI by AquesTalk.
  * This librarry supports I2C interface and "printf()" C format.
  * If ATP3011 talk number or alphabet you select printf(), 
@@ -1,22 +1,22 @@
  * This librarry supports I2C interface and "printf()" C format.
  * If ATP3011 talk number or alphabet you select printf(), 
- * otherwise, you have to use speach().
+ * otherwise, you have to use speech().
  * When you use printf(), the string must have "\n".
  *
@@ -36,14 +36,14 @@
     
     // if you send number or alphabet, you can use printf().
-    // oterwise, you have to use speach().
+    // oterwise, you have to use speech().
     